@@ -384,10 +384,12 @@ class ConcatenationVariable(Concatenation):
             np.min([child.bounds[1] for child in children]),
         )
 
-        if not any(c.print_name is None for c in children):
-            print_name = intersect(children[0].print_name, children[1].print_name)
+        if not any(c._raw_print_name is None for c in children):
+            print_name = intersect(
+                children[0]._raw_print_name, children[1]._raw_print_name
+            )
             for child in children[2:]:
-                print_name = intersect(print_name, child.print_name)
+                print_name = intersect(print_name, child._raw_print_name)
             if print_name.endswith("_"):
                 print_name = print_name[:-1]
         else:
