@@ -39,7 +39,7 @@ class LOQS(BaseModel):
         self.set_convection_submodel()
         self.set_porosity_submodel()
         self.set_active_material_submodel()
-        self.set_tortuosity_submodels()
+        self.set_transport_efficiency_submodels()
         self.set_electrolyte_submodel()
         self.set_electrode_submodels()
         self.set_thermal_submodel()
@@ -64,20 +64,26 @@ class LOQS(BaseModel):
         if self.options["operating mode"] == "current":
             self.submodels[
                 "leading order external circuit"
-            ] = pybamm.external_circuit.LeadingOrderExplicitCurrentControl(self.param)
+            ] = pybamm.external_circuit.LeadingOrderExplicitCurrentControl(
+                self.param, self.options
+            )
         elif self.options["operating mode"] == "voltage":
             self.submodels[
                 "leading order external circuit"
-            ] = pybamm.external_circuit.LeadingOrderVoltageFunctionControl(self.param)
+            ] = pybamm.external_circuit.LeadingOrderVoltageFunctionControl(
+                self.param, self.options
+            )
         elif self.options["operating mode"] == "power":
             self.submodels[
                 "leading order external circuit"
-            ] = pybamm.external_circuit.LeadingOrderPowerFunctionControl(self.param)
+            ] = pybamm.external_circuit.LeadingOrderPowerFunctionControl(
+                self.param, self.options
+            )
         elif callable(self.options["operating mode"]):
             self.submodels[
                 "leading order external circuit"
             ] = pybamm.external_circuit.LeadingOrderFunctionControl(
-                self.param, self.options["operating mode"]
+                self.param, self.options["operating mode"], self.options
             )
 
     def set_current_collector_submodel(self):
@@ -100,13 +106,13 @@ class LOQS(BaseModel):
             self.param, self.options, True
         )
 
-    def set_tortuosity_submodels(self):
+    def set_transport_efficiency_submodels(self):
         self.submodels[
-            "leading-order electrolyte tortuosity"
-        ] = pybamm.tortuosity.Bruggeman(self.param, "Electrolyte")
+            "leading-order electrolyte transport efficiency"
+        ] = pybamm.transport_efficiency.Bruggeman(self.param, "Electrolyte")
         self.submodels[
-            "leading-order electrode tortuosity"
-        ] = pybamm.tortuosity.Bruggeman(self.param, "Electrode")
+            "leading-order electrode transport efficiency"
+        ] = pybamm.transport_efficiency.Bruggeman(self.param, "Electrode")
 
     def set_convection_submodel(self):
 
