@@ -28,7 +28,6 @@ class SurfaceForm(BaseModel):
 
     def get_coupled_variables(self, variables):
 
-        param = self.param
         x_n = pybamm.standard_spatial_vars.x_n
         x_p = pybamm.standard_spatial_vars.x_p
         i_boundary_cc = variables["Current collector current density"]
@@ -37,10 +36,10 @@ class SurfaceForm(BaseModel):
         phi_s_cn = variables["Negative current collector potential"]
         T = variables[self.domain + " electrode temperature"]
 
+        conductivity = self.domain_param.sigma(T) * tor
         i_s = i_boundary_cc - i_e
 
         if self.domain == "Negative":
-            conductivity = param.sigma_n(T) * tor
             phi_s = phi_s_cn - pybamm.IndefiniteIntegral(i_s / conductivity, x_n)
 
         elif self.domain == "Positive":
@@ -48,7 +47,6 @@ class SurfaceForm(BaseModel):
             phi_e_s = variables["Separator electrolyte potential"]
             delta_phi_p = variables["Positive electrode surface potential difference"]
 
-            conductivity = param.sigma_p(T) * tor
             phi_s = -pybamm.IndefiniteIntegral(i_s / conductivity, x_p) + (
                 pybamm.boundary_value(phi_e_s, "right")
                 + pybamm.boundary_value(delta_phi_p, "left")
