@@ -83,4 +83,4 @@ class Full(BaseElectrolyteConductivity):
 
     def set_initial_conditions(self, variables):
         phi_e = variables["Electrolyte potential"]
-        self.initial_conditions = {phi_e: -self.param.U_n_init}
+        self.initial_conditions = {phi_e: -self.param.n.U_init}
