@@ -23,13 +23,13 @@ class Constant(BaseModel):
             eps_n = None
             deps_n_dt = None
         else:
-            eps_n = self.param.epsilon_n_init
+            eps_n = self.param.n.epsilon_init
             deps_n_dt = pybamm.FullBroadcast(
                 0, "negative electrode", "current collector"
             )
 
-        eps_s = self.param.epsilon_s_init
-        eps_p = self.param.epsilon_p_init
+        eps_s = self.param.s.epsilon_init
+        eps_p = self.param.p.epsilon_init
 
         deps_s_dt = pybamm.FullBroadcast(0, "separator", "current collector")
         deps_p_dt = pybamm.FullBroadcast(0, "positive electrode", "current collector")
