@@ -551,8 +551,7 @@ class Solution(object):
             pickle.dump(self, f, pickle.HIGHEST_PROTOCOL)
 
     def save_data(
-            self, filename=None, variables=None,
-            to_format="pickle", short_names=None
+        self, filename=None, variables=None, to_format="pickle", short_names=None
     ):
         """
         Save solution data only (raw arrays)
@@ -613,16 +612,12 @@ class Solution(object):
 
         if to_format == "pickle":
             if filename is None:
-                raise ValueError(
-                    "pickle format must be written to a file"
-                )
+                raise ValueError("pickle format must be written to a file")
             with open(filename, "wb") as f:
                 pickle.dump(data_short_names, f, pickle.HIGHEST_PROTOCOL)
         elif to_format == "matlab":
             if filename is None:
-                raise ValueError(
-                    "matlab format must be written to a file"
-                )
+                raise ValueError("matlab format must be written to a file")
             # Check all the variable names only contain a-z, A-Z or _ or numbers
             for name in data_short_names.keys():
                 # Check the string only contains the following ASCII:
@@ -676,6 +671,8 @@ class Solution(object):
 
     def __add__(self, other):
         """Adds two solutions together, e.g. when stepping"""
+        if other is None:
+            return self.copy()
         if not isinstance(other, Solution):
             raise pybamm.SolverError(
                 "Only a Solution or None can be added to a Solution"
@@ -831,8 +828,7 @@ def get_cycle_summary_variables(cycle_solution, esoh_sim):
     # Measured capacity variables
     if "Discharge capacity [A.h]" in model.variables:
         Q = cycle_solution["Discharge capacity [A.h]"].data
-        min_Q = np.min(Q)
-        max_Q = np.max(Q)
+        min_Q, max_Q = np.min(Q), np.max(Q)
 
         cycle_summary_variables.update(
             {
@@ -842,6 +838,15 @@ def get_cycle_summary_variables(cycle_solution, esoh_sim):
             }
         )
 
+    # Voltage variables
+    if "Battery voltage [V]" in model.variables:
+        V = cycle_solution["Battery voltage [V]"].data
+        min_V, max_V = np.min(V), np.max(V)
+
+        cycle_summary_variables.update(
+            {"Minimum voltage [V]": min_V, "Maximum voltage [V]": max_V}
+        )
+
     # Degradation variables
     degradation_variables = model.summary_variables
     first_state = cycle_solution.first_state
@@ -888,7 +893,7 @@ def get_cycle_summary_variables(cycle_solution, esoh_sim):
                     esoh_sim.parameter_values["Positive electrode OCP [V]"], tuple
                 ):
                     y_100_min = np.min(
-                        esoh_sim.parameter_values["Positive electrode OCP [V]"][1][:, 0]
+                        esoh_sim.parameter_values["Positive electrode OCP [V]"][1][0][0]
                     )
                     x_100_max = (
                         n_Li * pybamm.constants.F.value / 3600 - y_100_min * C_p
