@@ -13,7 +13,6 @@ import pickle
 import subprocess
 import sys
 import timeit
-import warnings
 from collections import defaultdict
 from platform import system
 
@@ -204,6 +203,9 @@ class TimerTime:
         output.append("1 second" if time == 1 else str(time) + " seconds")
         return ", ".join(output)
 
+    def __repr__(self):
+        return f"pybamm.TimerTime({self.value})"
+
     def __add__(self, other):
         if isinstance(other, numbers.Number):
             return TimerTime(self.value + other)
@@ -265,22 +267,6 @@ def load_function(filename):
     if filename.endswith(".py"):
         filename = filename.replace(".py", "")
 
-    # Replace `lead-acid` with `lead_acid`
-    if "lead-acid" in filename:
-        warnings.simplefilter("always", DeprecationWarning)
-        warnings.warn(
-            "lead-acid is deprecated, use lead_acid instead", DeprecationWarning
-        )
-        filename = filename.replace("lead-acid", "lead_acid")
-
-    # Replace `lithium-ion` with `lithium_ion`
-    if "lithium-ion" in filename:
-        warnings.simplefilter("always", DeprecationWarning)
-        warnings.warn(
-            "lithium-ion is deprecated, use lithium_ion instead", DeprecationWarning
-        )
-        filename = filename.replace("lithium-ion", "lithium_ion")
-
     # Assign path to _ and filename to tail
     _, tail = os.path.split(filename)
 
@@ -367,6 +353,19 @@ def get_parameters_filepath(path):
         return os.path.join(pybamm.__path__[0], path)
 
 
+def have_julia():
+    """
+    Checks whether the Julia programming language has been installed
+    """
+    # Try reading the julia version quietly to see whether julia is installed
+    FNULL = open(os.devnull, "w")
+    try:
+        subprocess.call(["julia", "--version"], stdout=FNULL, stderr=subprocess.STDOUT)
+        return True
+    except subprocess.CalledProcessError:  # pragma: no cover
+        return False
+
+
 def have_jax():
     """Check if jax and jaxlib are installed with the correct versions"""
     return (
